@@ -8,7 +8,6 @@ import requests
 from . import crypto
 from .exceptions import (
     ClientChallengeValidationError,
-    EncryptionKeyError,
     RequestValidationError,
     ResponseValidationError,
     ServerChallengeValidationError,
@@ -18,16 +17,13 @@ from .exceptions import (
 logger = logging.getLogger(__name__)
 
 
-def validate_request(
-    secret: str, private_key, headers: Mapping, body: Union[str, bytes]
-) -> Tuple[Mapping, str]:
+def validate_request(secret: str, headers: Mapping, body: Union[str, bytes]) -> Tuple[Mapping, str]:
     """Validates a request to an agent
 
     Args:
         headers (Mapping): The request headers
         body (str or bytes): The request body
         secret (str): The configured secret for the skill
-        private_key (TYPE): The configured private key for the skill
 
     Returns:
         Tuple[Mapping, str]: The decrypted request body and a challenge string
@@ -44,16 +40,11 @@ def validate_request(
         if not body:
             raise SignatureValidationError('Missing body')
 
-        try:
-            json_str = crypto.decrypt(private_key, body)
-        except EncryptionKeyError as exc:
-            raise RequestValidationError('Invalid payload encryption') from exc
-
-        if not crypto.verify_signature(secret, json_str, signature):
+        if not crypto.verify_signature(secret, body, signature):
             raise SignatureValidationError('Invalid signature')
 
         try:
-            request_json = json.loads(json_str)
+            request_json = json.loads(body)
         except json.JSONDecodeError as exc:
             raise RequestValidationError('Invalid request data') from exc
 
@@ -70,36 +61,8 @@ def validate_request(
     return request_json, challenge
 
 
-def validate_health_check(
-    secret: str, private_key, headers: Mapping, encrypted_challenge: str
-) -> str:
-    try:
-        signature = headers.get('X-Webex-Assistant-Signature')
-        if encrypted_challenge and not signature:
-            raise SignatureValidationError('Missing signature')
-        if signature and not encrypted_challenge:
-            raise ServerChallengeValidationError('Missing challenge')
-
-        try:
-            challenge = crypto.decrypt(private_key, encrypted_challenge)
-        except EncryptionKeyError as exc:
-            raise RequestValidationError('Invalid payload encryption') from exc
-
-        if not crypto.verify_signature(secret, challenge, signature):
-            raise SignatureValidationError('Invalid signature')
-
-    except RequestValidationError:
-        raise
-    except Exception as exc:
-        logger.exception('Unexpected error validating health check')
-        raise RequestValidationError('Cannot validate health check') from exc
-
-    return challenge
-
-
 def make_request(
     secret,
-    public_key,
     text,
     url='http://0.0.0.0:7150/parse',
     context=None,
@@ -130,14 +93,13 @@ def make_request(
     }
 
     encoded_request = json.dumps(request)
-    encrypted_request = crypto.encrypt(public_key, encoded_request)
 
     headers = {
         'X-Webex-Assistant-Signature': crypto.generate_signature(secret, encoded_request),
         'Content-Type': 'application/octet-stream',
         'Accept': 'application/json',
     }
-    res = requests.post(url, headers=headers, data=encrypted_request)
+    res = requests.post(url, headers=headers, data=encoded_request)
 
     if res.status_code != 200:
         raise ResponseValidationError('Request failed')
@@ -150,14 +112,13 @@ def make_request(
     return response_body
 
 
-def make_health_check(secret, public_key, url='http://0.0.0.0:7150/parse'):
+def make_health_check(secret, url='http://0.0.0.0:7150/parse'):
     challenge = os.urandom(64).hex()
-    encrypted_challenge = crypto.encrypt(public_key, challenge)
     headers = {
         'X-Webex-Assistant-Signature': crypto.generate_signature(secret, challenge),
         'Accept': 'application/json',
     }
-    res = requests.get(url, headers=headers, params={'payload': encrypted_challenge})
+    res = requests.get(url, headers=headers, params={'payload': challenge})
 
     if res.status_code != 200:
         raise ResponseValidationError('Health check failed')
